Learn R Programming

valorate (version 1.0-5)

valorate.plot.subpop: PLOT ALL ESTIMATED LOG-RANK DISTRIBUTIONS

Description

Plots all log-rank distributions estimated with the same object (different values of n1). This family of plots is commonly used to compare the estimated distributions.

Usage

valorate.plot.subpop.empirical(vro, which, 
  type, log, xlim, smooth, legends, 
  density, ylim, ...)

valorate.plot.subpop.empirical.to.0(vro, which, type, log, xlim, smooth, legends, density, ylim, ...)

valorate.plot.subpop.empirical.scaled(vro, which, type, log, xlim, smooth, legends, density, ylim, scale.point, ...)

Value

Nothing.

Arguments

vro

the valorate object.

which

The values of n1 that will be shown. NULL to plot them all.

type

typical plot parameter: "p"=points, "l"=lines (default), "o"=overlap.

log

typical plot parameter : specify which axis are shown in logarithm base 10.

xlim

typical plot parameter.

ylim

typical plot parameter.

smooth

the strength of density smoothing for display purposes. The default is 10.

legends

the number of columns in legends. 0 to omit legends.

density

indicates whether all curves should represent density (default to TRUE). FALSE to scale to maximum.

...

arguments passed to plot.

scale.point

a double between 0 and 0.5 (exclusive) that determines the two points in quantiles in which all densities will be 'equalized'. The quantiles are scale.point and 1-scale.point. 0.5 should be avoided.

Author

Victor Trevino vtrevino@itesm.mx

Details

valorate.plot.subpop.empirical plots all log-rank distributions estimated with the same object (different values of n1) in raw densities and scales. valorate.plot.subpop.empirical.to.0 is similar to valorate.plot.subpop.empirical but shift distributions to 0 and scale horizontal axis to similar limits. valorate.plot.subpop.empirical.scaled is similar to valorate.plot.subpop.empirical but scales the distributions to have the same scale.point(s) (in x) for all distributions. It also shifts all distribution to zero. This helps to compare the tendencies of the overall distributions.

References

Trevino et al. 2016 https://bioinformatics.mx/index.php/bioinfo-tools/

See Also

new.valorate. valorate.survdiff.

Examples

Run this code
## Create a random population of 100 subjects 
## having 20 events
subjects <- numeric(100)
subjects[sample(100,20)] <- 1
vo <- new.valorate(rank=subjects, sampling.size=100000, verbose=TRUE)

for (i in c(5,10,20,50)) {
  groups <- numeric(100)
  groups[sample(100,i)] <- 1 
  valorate.survdiff(vo, groups) 
}

if (FALSE) valorate.plot.subpop.empirical(vo)
if (FALSE) valorate.plot.subpop.empirical.to.0(vo)

Run the code above in your browser using DataLab